@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-persist.h,v 1.23 2005/08/17 17:31:22 chpe Exp $
+ *  $Id: ephy-embed-persist.h,v 1.24 2005/10/15 10:02:02 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_PERSIST_H
@@ -49,7 +49,8 @@ typedef enum
 	EPHY_EMBED_PERSIST_NO_VIEW		= 1 << 2,
 	EPHY_EMBED_PERSIST_ASK_DESTINATION	= 1 << 3,
 	EPHY_EMBED_PERSIST_DO_CONVERSION	= 1 << 4,
-	EPHY_EMBED_PERSIST_FROM_CACHE		= 1 << 5
+	EPHY_EMBED_PERSIST_FROM_CACHE		= 1 << 5,
+	EPHY_EMBED_PERSIST_NO_CERTDIALOGS	= 1 << 6
 } EphyEmbedPersistFlags;
 
 struct _EphyEmbedPersist
