@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-cache.c,v 1.56 2006/01/22 10:56:32 crispin Exp $
+ *  $Id: ephy-favicon-cache.c,v 1.57 2006/05/10 18:06:59 chpe Exp $
  */
 
 #include "config.h"
@@ -596,12 +596,8 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 
 	if (url == NULL) return NULL;
 
-#ifdef HAVE_GECKO_1_8
 	if (!g_str_has_prefix (url, "http://") &&
 	    !g_str_has_prefix (url, "https://")) return NULL;
-#else
-	if (!g_str_has_prefix (url, "http://")) return NULL;
-#endif
 
 	priv->requests += 1;
 
