@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.41 2006/03/02 19:41:23 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.43 2006/05/10 18:07:00 chpe Exp $
  */
 
 /*
@@ -27,61 +27,66 @@
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "EphyUtils.h"
-#include "AutoJSContextStack.h"
-
-#include <nsCOMPtr.h>
-#include <nsMemory.h>
-#include <nsIServiceManager.h>
-#include <nsIInterfaceRequestor.h>
-#include <nsIInterfaceRequestorUtils.h>
-#include <nsIX509Cert.h>
-#include <nsIX509CertValidity.h>
-#include <nsIX509CertDB.h>
-#include <nsIASN1Object.h>
-#include <nsIASN1Sequence.h>
-#include <nsICRLInfo.h>
-#include <nsISimpleEnumerator.h>
-#include <nsIArray.h>
-#include <nsIDOMWindow.h>
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
+#include <time.h>
 
 #include <glib/gi18n.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtktogglebutton.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkbutton.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkeditable.h>
+#include <gtk/gtkentry.h>
 #include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkeditable.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktextbuffer.h>
-#include <gtk/gtktextview.h>
 #include <gtk/gtkprogressbar.h>
 #include <gtk/gtksizegroup.h>
-#include <glade/glade-xml.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtktextbuffer.h>
+#include <gtk/gtktextview.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtktreestore.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtkvbox.h>
 #include <gconf/gconf-client.h>
-#include <time.h>
+#include <glade/glade-xml.h>
+
+#include <nsStringAPI.h>
+
+#include <nsCOMPtr.h>
+#include <nsIArray.h>
+#include <nsIASN1Object.h>
+#include <nsIASN1Sequence.h>
+#include <nsICRLInfo.h>
+#include <nsIDOMWindow.h>
+#include <nsIInterfaceRequestor.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsIServiceManager.h>
+#include <nsISimpleEnumerator.h>
+#include <nsIX509CertDB.h>
+#include <nsIX509Cert.h>
+#include <nsIX509CertValidity.h>
+#include <nsMemory.h>
+#include <nsServiceManagerUtils.h>
+
+#ifdef HAVE_NSIMUTABLEARRAY_H
+#include <nsIMutableArray.h>
+#endif
 
-#include "GtkNSSDialogs.h"
 #include "ephy-file-helpers.h"
 #include "ephy-gui.h"
 
+#include "AutoJSContextStack.h"
+#include "EphyUtils.h"
+
+#include "GtkNSSDialogs.h"
+
 NS_DEFINE_CID (kX509CertCID, NS_IX509CERT_IID);
 NS_DEFINE_CID (kASN1ObjectCID, NS_IASN1OBJECT_IID);
 
@@ -224,7 +229,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	
 	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      NULL);
+					      (char *) NULL);
 	if (gparent)
 	{
 		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
@@ -304,14 +309,14 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
 	char *first, *second, *msg;
 	int res;
 
-	nsEmbedString commonName;
+	nsString commonName;
 	cert->GetCommonName (commonName);
 
-	nsEmbedCString cCommonName;
+	nsCString cCommonName;
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
-	nsEmbedCString cTargetUrl (targetURL);
+	nsCString cTargetUrl (targetURL);
 
 	first = g_markup_printf_escaped (_("The site “%s” returned security information for "
 					   "“%s”. It is possible that someone is intercepting "
@@ -347,10 +352,10 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	char *secondary, *tertiary, *msg;
 	int res;
 
-	nsEmbedString commonName;
+	nsString commonName;
 	cert->GetCommonName (commonName);
 
-	nsEmbedCString cCommonName;
+	nsCString cCommonName;
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
@@ -444,10 +449,10 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 		timeToUse = notBefore;
 	}
 	
-	nsEmbedString commonName;
+	nsString commonName;
 	cert->GetCommonName (commonName);
 
-	nsEmbedCString cCommonName;
+	nsCString cCommonName;
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
@@ -494,21 +499,21 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_ERROR,
 			    &label, NULL);
 
-	nsEmbedString commonName;
+	nsString commonName;
 	cert->GetCommonName (commonName);
 
-	nsEmbedCString cCommonName;
+	nsCString cCommonName;
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
-	nsEmbedCString cTargetUrl (targetURL);
+	nsCString cTargetUrl (targetURL);
 
 	primary = g_markup_printf_escaped (_("Cannot establish connection to “%s”."),
 					   cTargetUrl.get());
@@ -559,7 +564,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 					      NSSDIALOG_RESPONSE_VIEW_CERT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("_Trust CA"),	GTK_RESPONSE_ACCEPT,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -573,10 +578,10 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 			    &label, NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
-	nsEmbedString commonName;
+	nsString commonName;
 	cert->GetCommonName (commonName);
 
-	nsEmbedCString cCommonName;
+	nsCString cCommonName;
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
@@ -642,7 +647,7 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -774,7 +779,7 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL,
 					      GTK_RESPONSE_CANCEL,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -868,7 +873,7 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	else
 	{
 		gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry1), 0, -1);
-		NS_CStringToUTF16 (nsEmbedCString (text),
+		NS_CStringToUTF16 (nsCString (text),
 			           NS_CSTRING_ENCODING_UTF8, _password);
 		g_free (text);
 		*_retval = PR_TRUE;
@@ -897,7 +902,7 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("I_mport Certificate"), GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -941,7 +946,7 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	else
 	{
 		gchar * text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-		NS_CStringToUTF16 (nsEmbedCString (text),
+		NS_CStringToUTF16 (nsCString (text),
 			           NS_CSTRING_ENCODING_UTF8, _password);
 		g_free (text);
 		*_retval = PR_TRUE;
@@ -999,7 +1004,7 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 					      GTK_WINDOW (gparent),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Certificate Revocation List Imported"));
@@ -1020,7 +1025,7 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 
-	nsEmbedString org, orgUnit, nextUpdate;
+	nsString org, orgUnit, nextUpdate;
 	rv = crl->GetOrganization (org);
 	if (NS_FAILED(rv)) return rv;
 
@@ -1031,15 +1036,15 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 	if (NS_FAILED(rv)) return rv;
 
 	int row = 0;
-	nsEmbedCString cOrg;
+	nsCString cOrg;
 	NS_UTF16ToCString (org, NS_CSTRING_ENCODING_UTF8, cOrg);
 	set_table_row (table, row, _("Organization:"), cOrg.get ());
 
-	nsEmbedCString cOrgUnit;
+	nsCString cOrgUnit;
 	NS_UTF16ToCString (orgUnit, NS_CSTRING_ENCODING_UTF8, cOrgUnit);
 	set_table_row (table, row, _("Unit:"), cOrgUnit.get ());
 
-	nsEmbedCString cNextUpdate;
+	nsCString cNextUpdate;
 	NS_UTF16ToCString (nextUpdate, NS_CSTRING_ENCODING_UTF8, cNextUpdate);
 	set_table_row (table, row, _("Next Update:"), cNextUpdate.get ());
 
@@ -1074,7 +1079,7 @@ set_label_cert_attribute (GladeXML* gxml, const char* label_id, nsAString &value
 	}
 	else
 	{
-		nsEmbedCString cValue;
+		nsCString cValue;
 		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cValue);
 		gtk_label_set_use_markup (GTK_LABEL (label), FALSE);
 		gtk_label_set_text (GTK_LABEL (label), cValue.get());
@@ -1107,11 +1112,11 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
 		gtk_tree_store_append (GTK_TREE_STORE (model), &iter, 
 				       (i == (int)numCerts-1) ? NULL : &parent);
 
-		nsEmbedString value;
+		nsString value;
 		rv = nsCert->GetCommonName (value);
 		if (NS_FAILED(rv)) return FALSE;
 
-		nsEmbedCString cValue;
+		nsCString cValue;
 		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cValue);
 
 		nsIX509Cert *nsCertP = nsCert;
@@ -1153,10 +1158,10 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
 static void
 add_asn1_object_to_tree(GtkTreeModel *model, nsIASN1Object *object, GtkTreeIter *parent)
 {
-	nsEmbedString dispNameU;
+	nsString dispNameU;
 	object->GetDisplayName(dispNameU);
 
-	nsEmbedCString cDispNameU;
+	nsCString cDispNameU;
 	NS_UTF16ToCString (dispNameU, NS_CSTRING_ENCODING_UTF8, cDispNameU);
 
 	GtkTreeIter iter;
@@ -1235,10 +1240,10 @@ field_tree_view_selection_changed_cb (GtkTreeSelection *selection,
 
 		gtk_tree_model_get (model, &iter, 1, &object, -1);
 
-		nsEmbedString dispValU;
+		nsString dispValU;
 		object->GetDisplayValue(dispValU);
 
-		nsEmbedCString cDispValU;
+		nsCString cDispValU;
 		NS_UTF16ToCString (dispValU, NS_CSTRING_ENCODING_UTF8, cDispValU);
 
 		gtk_text_buffer_set_text (text_buffer, cDispValU.get(), -1);
@@ -1278,7 +1283,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						     0, "Certificate",
 						     renderer,
 						     "text", 0,
-						     NULL);
+						     (char *) NULL);
 
 	GtkTreeSelection *select = gtk_tree_view_get_selection (GTK_TREE_VIEW (chain_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
@@ -1299,7 +1304,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						     0, "Certificate Field",
 						     renderer,
 						     "text", 0,
-						     NULL);
+						     (char *) NULL);
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (field_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
@@ -1333,7 +1338,7 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 {
 	GtkWidget *dialog, *widget;
 	GladeXML *gxml;
-	nsEmbedString value;
+	nsString value;
 	PRUint32 verifystate, count;
 	PRUnichar ** usage;
 	GtkSizeGroup * sizegroup;
@@ -1422,8 +1427,8 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 		GtkWidget *indent;
 		for (PRUint32 i = 0 ; i < count ; i++)
 		{
-			nsEmbedCString msg;
-			NS_UTF16ToCString (nsEmbedString(usage[i]),
+			nsCString msg;
+			NS_UTF16ToCString (nsString(usage[i]),
 					   NS_CSTRING_ENCODING_UTF8, msg);
 
 			GtkWidget *label = gtk_label_new(msg.get());
