@@ -38,31 +38,32 @@
  *
  *  Copyright (C) 2005 Christian Persch
  *
- *  $Id: GtkNSSSecurityWarningDialogs.cpp,v 1.13 2006/03/02 19:41:23 chpe Exp $
+ *  $Id: GtkNSSSecurityWarningDialogs.cpp,v 1.14 2006/05/10 18:07:00 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "GtkNSSSecurityWarningDialogs.h"
-#include "EphyUtils.h"
-#include "AutoJSContextStack.h"
+#include <glib/gi18n.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkvbox.h>
 
 #include <nsCOMPtr.h>
+#include <nsIDOMWindow.h>
+#include <nsIInterfaceRequestor.h>
+#include <nsIInterfaceRequestorUtils.h>
 #include <nsIPrefBranch.h>
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
-#include <nsIInterfaceRequestor.h>
-#include <nsIInterfaceRequestorUtils.h>
-#include <nsIDOMWindow.h>
+#include <nsServiceManagerUtils.h>
 
-#include <glib/gi18n.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtklabel.h>
+#include "AutoJSContextStack.h"
+#include "EphyUtils.h"
+
+#include "GtkNSSSecurityWarningDialogs.h"
 
 NS_IMPL_THREADSAFE_ISUPPORTS1 (GtkNSSSecurityWarningDialogs, nsISecurityWarningDialogs)
 
@@ -213,7 +214,7 @@ GtkNSSSecurityWarningDialogs::DoDialog (nsIInterfaceRequestor *aContext,
 	PRBool showOnce = PR_FALSE;
 	if (!show && prefBranch && aPrefName)
 	{
-		showOncePref = g_strconcat (aPrefName, ".show_once", NULL);
+		showOncePref = g_strconcat (aPrefName, ".show_once", (char *) NULL);
 		rv = prefBranch->GetBoolPref (showOncePref, &showOnce);
 		if (NS_FAILED (rv)) showOnce = PR_FALSE;
 	}
