@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.47 2005/11/01 11:15:55 chpe Exp $
+ *  $Id: print-dialog.c,v 1.49 2006/01/03 14:42:04 chpe Exp $
  */
 
 #include "config.h"
@@ -63,7 +63,6 @@ enum
 	PAGE_NUMBERS_PROP,
 	DATE_PROP,
 	COLOR_PROP,
-	PAPER_SELECTOR_PROP,
 };
 
 static const
@@ -75,7 +74,6 @@ EphyDialogProperty setup_props [] =
 	{ "print_page_numbers_checkbutton",	CONF_PRINT_PAGE_NUMBERS,  PT_AUTOAPPLY, 0 },
 	{ "print_date_checkbutton",		CONF_PRINT_DATE,	  PT_AUTOAPPLY, 0 },
 	{ "print_color_radiobutton",		CONF_PRINT_COLOR,	  PT_AUTOAPPLY, 0 },
-	{ "print_paper_selector_hbox",		NULL,			  PT_NORMAL,    0 },
 
 	{ NULL }
 };
@@ -146,14 +144,6 @@ ephy_print_save_config_to_file (GnomePrintConfig *config)
 	g_free (str);
 }
 
-static void
-ephy_print_save_config_to_file_and_unref (GnomePrintConfig *config)
-{
-	ephy_print_save_config_to_file (config);
-	
-	g_object_unref (G_OBJECT (config));
-}
-
 EmbedPrintInfo *
 ephy_print_get_print_info (void)
 {
@@ -280,9 +270,8 @@ ephy_print_verify_postscript (GnomePrintDialog *print_dialog)
                                 config, (guchar *)"Settings.Engine.Backend.Driver"));
         }
 
-	if (GTK_WINDOW (print_dialog)->group)
-		gtk_window_group_add_window (GTK_WINDOW (print_dialog)->group,
-					     GTK_WINDOW (dialog));
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (print_dialog)),
+				     GTK_WINDOW (dialog));
 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -352,23 +341,6 @@ ephy_print_setup_dialog_response_cb (GtkWidget *widget,
 	g_object_unref (dialog);
 }
 
-static GtkWidget *
-ephy_print_paper_selector_new ()
-{
-	GtkWidget *paper_selector;
-	GnomePrintConfig *config;
-	
-	config = ephy_print_load_config_from_file ();
-
-	paper_selector = gnome_paper_selector_new_with_flags (config,
-						GNOME_PAPER_SELECTOR_MARGINS);
-	
-	g_object_set_data_full (G_OBJECT (paper_selector), "config", config,
-				(GDestroyNotify) ephy_print_save_config_to_file_and_unref);
-	
-	return paper_selector;
-}
-
 /*
  * A variant of gnome_print_dialog_construct_range_page that can be used when
  * the total page count is unknown. It defaults to 1-1
@@ -450,10 +422,9 @@ ephy_print_dialog_new (GtkWidget *parent,
 			  G_CALLBACK (ephy_print_dialog_response_cb), info);
 	
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
-	
-	if (GTK_WINDOW (parent)->group)
-		gtk_window_group_add_window (GTK_WINDOW (parent)->group,
-					     GTK_WINDOW (dialog));
+
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
+				     GTK_WINDOW (dialog));
 
 	return dialog;
 }
@@ -463,7 +434,6 @@ ephy_print_setup_dialog_new (void)
 {
 	EphyDialog *dialog;
 	GtkWidget *window;
-	GtkWidget *paper_selector_hbox;
 
 	dialog = EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG, NULL));
 
@@ -474,15 +444,8 @@ ephy_print_setup_dialog_new (void)
 			       NULL);
 
 	window = ephy_dialog_get_control (dialog, setup_props[SETUP_WINDOW_PROP].id);
-	gtk_window_set_icon_name (GTK_WINDOW (window), STOCK_PRINT_SETUP);
 	g_signal_connect (window, "response",
 			  G_CALLBACK (ephy_print_setup_dialog_response_cb), dialog);
 
-	paper_selector_hbox = ephy_dialog_get_control (dialog,
-						setup_props[PAPER_SELECTOR_PROP].id);
-	gtk_box_pack_start_defaults (GTK_BOX (paper_selector_hbox),
-			   ephy_print_paper_selector_new ());
-	gtk_widget_show_all (paper_selector_hbox);
-
 	return dialog;
 }
