@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.69 2005/11/10 21:32:33 crispin Exp $
+ *  $Id: ephy-location-entry.c,v 1.73 2006/04/15 13:19:21 tko Exp $
  */
 
 #include "config.h"
@@ -337,9 +337,13 @@ update_favicon (EphyLocationEntry *entry)
 	}
 	else
 	{
-		gtk_image_set_from_stock (image,
-					  GTK_STOCK_NEW,
-					  GTK_ICON_SIZE_MENU);
+		/* Here we could consider using fallback favicon that matches
+		 * the page MIME type, though text/html should be good enough
+		 * most of the time. See #337140
+		 */
+		gtk_image_set_from_icon_name (image,
+					      "text-html",
+					      GTK_ICON_SIZE_MENU);
 	}
 }
 
@@ -380,7 +384,8 @@ entry_key_press_cb (GtkEntry *entry,
 	if ((event->keyval == GDK_Return ||
 	     event->keyval == GDK_KP_Enter ||
 	     event->keyval == GDK_ISO_Enter) &&
-	    state == GDK_CONTROL_MASK)
+	    (state == GDK_CONTROL_MASK ||
+	     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)))
 	{
 		gtk_im_context_reset (entry->im_context);
 
@@ -388,7 +393,8 @@ entry_key_press_cb (GtkEntry *entry,
 
 		return TRUE;
 	}
-	else if (event->keyval == GDK_Escape && state == 0)
+
+	if (event->keyval == GDK_Escape && state == 0)
 	{
 		ephy_location_entry_reset (lentry);
 		/* don't return TRUE since we want to cancel the autocompletion popup too */
@@ -870,8 +876,7 @@ ephy_location_entry_init (EphyLocationEntry *le)
 	p->user_changed = TRUE;
 
 	p->tips = gtk_tooltips_new ();
-	g_object_ref (p->tips);
-	gtk_object_sink (GTK_OBJECT (p->tips));
+	g_object_ref_sink (p->tips);
 
 	ephy_location_entry_construct_contents (le);
 
@@ -997,6 +1002,9 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 	gtk_entry_set_text (GTK_ENTRY (priv->icon_entry->entry), text);
 	priv->user_changed = TRUE;
 
+	/* We need to call update_address_state() here, as the 'changed' signal
+	 * may not get called if the user has typed in the exact correct url */
+	update_address_state (entry);
 	update_favicon (entry);
 
 	/* Now restore the selection.
