@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action-group.h,v 1.2 2006/01/24 23:21:31 chpe Exp $
+ *  $Id: ephy-topic-action-group.h,v 1.3 2006/02/10 22:49:29 chpe Exp $
  */
 
 #ifndef EPHY_TOPIC_ACTION_GROUP_H
@@ -29,7 +29,8 @@
 
 G_BEGIN_DECLS
 
-GtkActionGroup * ephy_topic_group_new (EphyNode *node, GtkUIManager *manager);
+GtkActionGroup	*ephy_topic_action_group_new	(EphyNode *node,
+						 GtkUIManager *manager);
 
 G_END_DECLS
 
